@@ -1,51 +1,79 @@
 #' Value of a function at regularly spaced points
 #'
-#' Evaluates a function at points on a triangular grid. 
-#' Intended to facilitate coloured contour plots with \code{\link{ColourTernary}}.
+#' Intended to facilitate coloured contour plots with [`ColourTernary()`],
+#' `TernaryPointValue()` evaluates a function at points on a triangular grid;
+#' `TernaryDensity()` calculates the density of points in each grid cell.
+#' 
 #' 
-#' Density plotting functions are somewhat experimental; please
-#' \href{https://github.com/ms609/Ternary/issues/new}{report any issues}.
-#'
 #' @template FuncParam
 #' @template resolutionParam
 #' @template directionParam
-#' @return A matrix whose rows correspond to:
+#' @param \dots Additional parameters to `Func()`.
+#' @return `TernaryPointValues()` returns a matrix whose rows correspond to:
 #' 
-#'   **x**, **y**: co-ordinates of the centres of smaller triangles
+#' - **x**, **y**: co-ordinates of the centres of smaller triangles
 #'   
-#'   **z**: The value of `Func(a, b, c)`, where `a`, `b` and `c` are the 
+#' - **z**: The value of `Func(a, b, c)`, where `a`, `b` and `c` are the 
 #'   ternary coordinates of `x` and `y`.
 #'   
-#'   **down**: `0` if the triangle concerned points upwards (or right), 
+#' - **down**: `0` if the triangle concerned points upwards (or right), 
 #'   `1` otherwise
 #' 
+#' @examples
+#' TernaryPointValues(function (a, b, c) a * b * c, resolution = 2)
+#' 
+#' TernaryPlot(grid.lines = 4)
+#' cols <- TernaryPointValues(rgb, resolution = 4)
+#' text(as.numeric(cols['x', ]), as.numeric(cols['y', ]),
+#'      labels =  ifelse(cols['down', ] == '1', 'v', '^'),
+#'      col = cols['z', ])
+#' 
+#' TernaryPlot(axis.labels = seq(0, 10, by = 1))
+#' 
+#' nPoints <- 4000L
+#' coordinates <- cbind(abs(rnorm(nPoints, 2, 3)),
+#'                      abs(rnorm(nPoints, 1, 1.5)),
+#'                      abs(rnorm(nPoints, 1, 0.5)))
+#' 
+#' density <- TernaryDensity(coordinates, resolution = 10L)
+#' ColourTernary(density)
+#' TernaryPoints(coordinates, col = 'red', pch = '.')
+#' 
 #' @family contour plotting functions
-#' @author Martin R. Smith
+#' @template MRS
 #' @export
 TernaryPointValues <- function(Func, resolution = 48L, 
-                               direction = getOption('ternDirection')) {
+                               direction = getOption('ternDirection'), ...) {
   triangleCentres <- TriangleCentres (resolution, direction)
   x <- triangleCentres['x', ]
   y <- triangleCentres['y', ]
   abc <- XYToTernary(x, y, direction)
   
   # Return:
-  rbind(x = x, y = y, z = Func(abc[1, ], abc[2, ], abc[3, ]), 
+  rbind(x = x, y = y, z = Func(abc[1, ], abc[2, ], abc[3, ], ...), 
         down = triangleCentres['triDown', ])
 }
 
 #' Coordinates of triangle mid-points
 #' 
+#' Calculate _x_ and _y_ coordinates of the midpoints of triangles
+#' tiled to cover a ternary plot.
+#' 
 #' @template resolutionParam
 #' @template directionParam
 #' 
-#' @return A matrix containing three named rows:
+#' @return `TriangleCentres()` returns a matrix with three named rows:
 #'  - `x` _x_ coordinates of triangle midpoints;
 #'  - `y` _y_ coordinates of triangle midpoints;
-#'  - `triDown` binary integer specifying whether given triangle points down.
+#'  - `triDown` `0` for upwards-pointing triangles, `1` for downwards-pointing.
 #'  
+#' @examples
+#' TernaryPlot(grid.lines = 4)
+#' centres <- TriangleCentres(4)
+#' text(centres['x', ], centres['y', ], ifelse(centres['triDown', ], 'v', '^'))
+#'
 #' @family coordinate translation functions
-#' @author Martin R. Smith
+#' @template MRS
 #' @export
 TriangleCentres <- function (resolution = 48L, 
                              direction = getOption('ternDirection')) {
@@ -119,7 +147,7 @@ TriangleCentres <- function (resolution = 48L,
   rbind(x, y, triDown)
 }
 
-#' @describeIn TernaryPointValues Returns the density of points in each triangle
+#' @rdname TernaryPointValues
 #' @template coordinatesParam
 #' @export
 TernaryDensity <- function (coordinates, resolution = 48L, direction = getOption('ternDirection')) {
@@ -342,15 +370,17 @@ TernaryRightTiles <- function(x, y, resolution, col) {
 #' 
 #' TernaryPlot()
 #' 
-#' values <- TernaryPointValues(FunctionToContour, resolution=24L)
+#' values <- TernaryPointValues(FunctionToContour, resolution = 24L)
 #' ColourTernary(values)
 #' TernaryContour(FunctionToContour, resolution=36L)
 #' 
 #' 
-#' @author Martin R. Smith
+#' @template MRS
 #' 
+#' @family functions for colouring and shading
 #' @export
-TernaryTiles <- function (x, y, down, resolution, col, direction = getOption('ternDirection')) {
+TernaryTiles <- function (x, y, down, resolution, col, 
+                          direction = getOption('ternDirection')) {
   down <- as.logical(down)
   if (direction %% 2) {
     TernaryDownTiles(x[down], y[down], resolution, col[down])
@@ -366,30 +396,65 @@ TernaryTiles <- function (x, y, down, resolution, col, direction = getOption('te
 
 #' Colour a ternary plot according to the output of a function
 #' 
-#' @param values Numeric vector specifying the values associated with each point, 
-#' generated using [`TernaryPointValues`].
-#' @param spectrum Vector of colours to use as a spectrum.
+#' @param values Numeric matrix specifying the values associated with each
+#' point, generated using [`TernaryPointValues`].
+#' @param spectrum Vector of colours to use as a spectrum, or `NULL` to use
+#' `values['z', ]`.
 #' @template resolutionParam
 #' @template directionParam
 #' 
-#' @author Martin R. Smith
+#' @template MRS
+#' 
+#' @examples 
+#' TernaryPlot(alab = 'a', blab = 'b', clab = 'c')
+#'  
+#' FunctionToContour <- function (a, b, c) {
+#'   a - c + (4 * a * b) + (27 * a * b * c)
+#' }
+#' 
+#' values <- TernaryPointValues(FunctionToContour, resolution = 24L)
+#' ColourTernary(values)
+#' TernaryContour(FunctionToContour, resolution = 36L)
+#' 
+#' 
+#' TernaryPlot()
+#' values <- TernaryPointValues(rgb, resolution = 20)
+#' ColourTernary(values, spectrum = NULL)
 #' 
 #' @family contour plotting functions
+#' @family functions for colouring and shading
 #' @importFrom viridisLite viridis
+#' @importFrom grDevices col2rgb
 #' @export
-ColourTernary <- function (values, spectrum = viridisLite::viridis(256L, alpha=0.6),
+ColourTernary <- function (values, 
+                           spectrum = viridisLite::viridis(256L, alpha = 0.6),
                            resolution = sqrt(ncol(values)),
                            direction = getOption('ternDirection')) {
   z <- values['z', ]
-  zNorm <- z - min(z)
-  zNorm <- zNorm / max(zNorm)
-  TernaryTiles(values['x', ], values['y', ], values['down', ], resolution = resolution, 
-               col=spectrum[as.integer(zNorm * (length(spectrum) - 1L)) + 1L], 
-               direction = direction)
+  col <- if (is.null(spectrum) || (!is.numeric(z) && all(
+      suppressWarnings(is.na(as.numeric(z)))) && 
+      tryCatch(is.matrix(col2rgb(z)), error = function(e) FALSE))) {
+    z
+  } else {
+    if (!is.numeric(z)) {
+      stop("values['z', ] must be numeric.\nTo colour by values['z', ], set `spectrum = FALSE`.")
+    }
+    zNorm <- z - min(z)
+    zNorm <- zNorm / max(zNorm)
+    spectrum[as.integer(zNorm * (length(spectrum) - 1L)) + 1L]
+  }
+  TernaryTiles(as.numeric(values['x', ]), as.numeric(values['y', ]),
+               as.numeric(values['down', ]),
+               resolution = resolution, col = col, direction = direction)
+  
   # Return:
   invisible()
 }
 
+#' @rdname ColourTernary
+#' @export
+ColorTernary <- ColourTernary
+
 #' Add contours to a ternary plot
 #' 
 #' Draws contour lines to depict the value of a function in ternary space.
@@ -399,7 +464,18 @@ ColourTernary <- function (values, spectrum = viridisLite::viridis(256L, alpha=0
 #' @template directionParam
 #' @template dotsToContour
 #' 
-#' @author Martin R. Smith
+#' @template MRS
+#' 
+#' @examples
+#' TernaryPlot(alab = 'a', blab = 'b', clab = 'c')
+#'  
+#' FunctionToContour <- function (a, b, c) {
+#'   a - c + (4 * a * b) + (27 * a * b * c)
+#' }
+#' 
+#' values <- TernaryPointValues(FunctionToContour, resolution = 24L)
+#' ColourTernary(values)
+#' TernaryContour(FunctionToContour, resolution = 36L)
 #' 
 #' @family contour plotting functions
 #' @importFrom graphics contour
@@ -432,10 +508,10 @@ TernaryContour <- function (Func, resolution = 96L, direction = getOption('ternD
 
 #' Add contours of estimated point density to a ternary plot
 #' 
-#' Uses two-dimensional kernel density estimation to plot contours of 
+#' Use two-dimensional kernel density estimation to plot contours of 
 #' point density.
 #' 
-#' This function is modelled on MASS::kde2d, which uses
+#' This function is modelled on `MASS::kde2d()`, which uses
 #' "an axis-aligned bivariate normal kernel, evaluated on a square grid".
 #' 
 #' This is to say, values are calculated on a square grid, and contours fitted
@@ -461,7 +537,7 @@ TernaryContour <- function (Func, resolution = 96L, direction = getOption('ternD
 #' 
 #' @template coordinatesParam
 #' @param bandwidth Vector of bandwidths for x and y directions. 
-#' Defaults to normal reference bandwidth (see MASS::bandwidth.nrd).
+#' Defaults to normal reference bandwidth (see `MASS::bandwidth.nrd`).
 #' A scalar value will be taken to apply to both directions.
 #' @template resolutionParam
 #' @param tolerance Numeric specifying how close to the margins the contours 
@@ -471,9 +547,23 @@ TernaryContour <- function (Func, resolution = 96L, direction = getOption('ternD
 #' @template dotsToContour
 #' @param edgeCorrection Logical specifying whether to correct for edge effects
 #'  (see details).
+#'  
+#' @examples
+#' 
+#' TernaryPlot(axis.labels = seq(0, 10, by = 1))
+#' 
+#' nPoints <- 400L
+#' coordinates <- cbind(abs(rnorm(nPoints, 2, 3)),
+#'                      abs(rnorm(nPoints, 1, 1.5)),
+#'                      abs(rnorm(nPoints, 1, 0.5)))
+#' 
+#' ColourTernary(TernaryDensity(coordinates, resolution = 10L))
+#' TernaryPoints(coordinates, col = 'red', pch = '.')
+#' TernaryDensityContour(coordinates, resolution = 30L)
+#'  
+#' @author Adapted from `MASS::kde2d()` by Martin R. Smith
 #' 
 #' @family contour plotting functions
-#' @author Adapted from MASS::kde2d by Martin R. Smith
 #' @importFrom stats dnorm quantile var
 #' @export
 TernaryDensityContour <- function (coordinates, bandwidth, resolution = 25L, 
